div.omnilib {
    margin-top: 24px;
}

div.omnilib-badges {
    margin-top: 12px;
    margin-bottom: 10px;
}

div.omnilib-badges a {
    color: #bbb;
    text-decoration: none;
    font-size: 24px;
    border: none;
}

div.omnilib-badges a:hover {
    color: #777;
    border: none;
}